@@ -39,7 +39,12 @@
 #define ORIG__EXIT __wrap__exit
 #define ORIG_ABORT __wrap_abort
 #define ORIG_MAIN __wrap_main
+
 #endif
+
+extern void abort (void);
+extern void exit (int);
+
 #endif
 
 #ifdef REAL_MAIN
